@@ -362,7 +362,7 @@ class Database(object):
         return d
 
     def _encodeID(self, id):
-        return urllib.quote(id)
+        return urllib.quote(id, '')
 
     @defer.inlineCallbacks
     def _save(self, doc, d, **ka):
